import MapUtil from './../MapUtil';
import GeoUtil from './../GeoUtil';
import Bridge from './../Bridge';

export default {
  mapUtil: null,
  // 标记
  markers: null,
  // 标签
  label: null,
  // 地区
  district: null,
  districtPolygons: null,
  // 多边形
  polygon: null,
  // 圆形
  circle: null,
  // 初始化地图
  initMap: function initMap(container, center) {
    var self = this;
    Bridge.showLoading();
    var mapUtil = new MapUtil(container, {
      // 缩放导航
      navigation: {
        position: 'bottom-right',
        type: 'zoom'
      },
      // 中心位置
      center: {
        center: center
      }
    });
    mapUtil.map.addEventListener('load', function (e) {
      Bridge.hideLoading();
      // 加载完成开始绘制
      self.mapUtil = mapUtil;
      console.log('初始化地图完成');
    }, false);
  },
  // 标记: 绘制标记
  drawMarkers: function drawMarkers(points) {
    var self = this;
    if (!self.mapUtil) {
      setTimeout(function () {
        self.drawMarkers(points);
      }, 500);
      return;
    }
    if (self.markers) {
      self.mapUtil.clearOverlays(self.markers);
    }
    self.markers = [];
    var bdPoints = [];
    for (var _iterator = points, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
      var _ref;

      if (_isArray) {
        if (_i >= _iterator.length) break;
        _ref = _iterator[_i++];
      } else {
        _i = _iterator.next();
        if (_i.done) break;
        _ref = _i.value;
      }

      var point = _ref;

      var bdPoint = GeoUtil.coordtransform(point);
      bdPoints.push(bdPoint);
      self.markers.push(self.drawMarker(bdPoint));
    }
    setTimeout(function () {
      self.mapUtil.centerToPoints(bdPoints);
      console.log('绘制标记完成');
    }, 500);
  },
  drawMarker: function drawMarker(bdPoint) {
    if (!bdPoint) {
      console.error('绘制标记: 定位坐标错误');
      return null;
    }
    var marker = this.mapUtil.drawMarker(bdPoint, {
      options: {
        iconStyle: {
          width: '16px',
          height: '27px',
          backgroundImage: 'url(//res.waiqin365.com/d/seedsui/mapview/location_red_shadow.png)'
        }
      }
    });
    return marker;
  },
  // 圆形: 绘制标签
  drawLabel: function drawLabel(point, radius) {
    var self = this;
    var bdPoint = GeoUtil.coordtransform(point);
    if (!self.mapUtil) {
      setTimeout(function () {
        self.drawLabel(bdPoint, radius);
      }, 500);
      return;
    }
    if (!self.label) {
      self.label = self.mapUtil.drawLabel(bdPoint, '\u534A\u5F84' + radius + '\u7C73', {
        offset: {
          width: 0,
          height: 14
        },
        style: {
          pointerEvents: 'none'
        }
      });
    } else {
      self.label.setPosition(bdPoint);
      self.label.setContent('\u534A\u5F84' + Math.trunc(radius, 2) + '\u7C73');
    }
  },
  // 绘制圆形
  drawCircle: function drawCircle(point, radius) {
    var self = this;
    if (!point || point.length !== 2) return;
    if (!radius) return;
    if (!self.mapUtil) {
      setTimeout(function () {
        self.drawCircle(point, radius);
      }, 500);
      return;
    }
    if (self.circle) {
      self.mapUtil.clearOverlay(self.circle);
    }
    var bdPoint = GeoUtil.coordtransform(point);
    var circle = self.mapUtil.drawCircle(bdPoint, radius);
    if (!circle) return;
    setTimeout(function () {
      self.mapUtil.centerToCircle(circle, {
        zoomFactor: -1
      });
    }, 300);
    self.circle = circle;
    console.log('绘制圆形完成');
    self.drawLabel(point, radius);
  },
  // 绘制多边形
  drawPolygon: function drawPolygon(polygon) {
    var self = this;
    if (!polygon || !polygon.length) return;
    if (!self.mapUtil) {
      setTimeout(function () {
        self.drawPolygon(polygon);
      }, 500);
      return;
    }
    var bdPolygons = polygon.map(function (point) {
      return GeoUtil.coordtransform(point);
    });
    if (self.polygon) {
      self.mapUtil.clearOverlay(self.polygon);
    }
    self.polygon = self.mapUtil.drawPolygon(bdPolygons);
    self.mapUtil.centerToPoints(bdPolygons);
    console.log('绘制多边形完成');
  },
  /**
   * 地区
   */
  drawDistrict: function drawDistrict(districtName) {
    var self = this;
    if (!districtName) return;
    if (!self.mapUtil) {
      setTimeout(function () {
        self.drawDistrict(districtName);
      }, 500);
      return;
    }
    if (self.district) {
      self.mapUtil.clearOverlays(self.district);
    }
    self.mapUtil.drawBoundary(districtName, null, {
      success: function success(res) {
        self.district = res.bdPolygons;
        self.districtPolygons = res.polygons;
        self.mapUtil.centerToPoints(res.bdPolygonsPath);
        console.log('绘制区域完成');
      },
      fail: function fail(err) {
        Bridge.showToast('\u6682\u65E0' + districtName + '\u7684\u8FB9\u754C\u6570\u636E', { mask: false });
      }
    });
  },
  destroy: function destroy() {
    var self = this;
    console.log('移除标注');
    self.mapUtil = null;
    // 标记
    self.markers = null;
    // 标签
    self.label = null;
    // 地区
    self.district = null;
    self.districtPolygons = null;
    // 多边形
    self.polygon = null;
    // 圆形
    self.circle = null;
  }
};